@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Controller.php 459 2007-02-18 20:30:55Z ichii386 $
+ *  @version    $Id: Ethna_Controller.php 516 2008-04-30 16:30:05Z mumumu-org $
  */
 
 // {{{ Ethna_Controller
@@ -58,6 +58,7 @@ class Ethna_Controller
         'tmp'           => 'tmp',
         'view'          => 'app/view',
         'www'           => 'www',
+        'test'          => 'app/test',
     );
 
     /** @var    array       DB */
@@ -467,13 +468,24 @@ class Ethna_Controller
      *  ӥ塼ǥ쥯ȥ̾ꤹ
      *
      *  @access public
-     *  @return string  ǥ쥯ȥ
+     *  @return string  ӥ塼ǥ쥯ȥ
      */
     function getViewdir()
     {
         return (empty($this->directory['view']) ? ($this->base . (empty($this->base) ? '' : '/')) : ($this->directory['view'] . "/"));
     }
 
+    /**
+     *  (action,viewʳ)ƥȥ֤ǥ쥯ȥ̾ꤹ
+     *
+     *  @access public
+     *  @return string  ƥȥ֤ǥ쥯ȥ
+     */
+    function getTestdir()
+    {
+        return (empty($this->directory['test']) ? ($this->base . (empty($this->base) ? '' : '/')) : ($this->directory['test'] . "/"));
+    }
+
     /**
      *  ץꥱǥ쥯ȥ֤
      *
@@ -836,6 +848,9 @@ class Ethna_Controller
         // ̾μ
         $action_name = $this->_getActionName($default_action_name, $fallback_action_name);
 
+        // ޥ͡¹ԥå
+        $this->_ethnaManagerEnabledCheck($action_name);
+
         // μ
         $action_obj =& $this->_getAction($action_name);
         if (is_null($action_obj)) {
@@ -2078,6 +2093,43 @@ class Ethna_Controller
 
     }
 
+    /**
+     *  Ethnaޥ͡㤬¹Բǽå
+     *
+     *  Ethnaޥ͡¹Ԥ褦ؼƤˤؤ餺
+     *  debug  trueǤʤϼ¹Ԥߤ롣
+     *
+     *  @access private
+     */
+    function _ethnaManagerEnabledCheck($action_name)
+    {
+        if ($this->config->get('debug') == false
+         && ($action_name == '__ethna_info__' || $action_name == '__ethna_unittest__')) {
+            $this->ethnaManagerCheckErrorMsg($action_name);
+            exit(0);
+        }
+    }
+
+    /**
+     *  Ethnaޥ͡㤬¹ǽʾΥ顼å
+     *  ɽ롣ѾԹǤΥåϤʤ
+     *  ϡΥ᥽åɤ򥪡С饤ɤ
+     *
+     *  @access protected
+     */
+     function ethnaManagerCheckErrorMsg($action_name)
+     {
+         $appid = strtolower($this->getAppId());
+         $run_action = ($action_name == '__ethna_info__')
+                     ? ' show Application Info List '
+                     : ' run Unit Test ';
+         echo "Ethna cannot {$run_action} under your application setting.<br>";
+         echo "HINT: You must set {$appid}/etc/{$appid}-ini.php debug setting 'true'.<br>";
+         echo "<br>";
+         echo "In {$appid}-ini.php, please set as follows :<br><br>";
+         echo "\$config = array ( 'debug' => true, );";
+     } 
+
     /**
      *  CLI¹ե饰
      *
